@@ -84,10 +84,10 @@ namespace KBibTeX
         setAcceptDrops( TRUE );
         setDropVisualizer( TRUE );
 
-        connect( header(), SIGNAL( clicked( int ) ), this, SLOT( setSortingColumn( int ) ) );
-        connect( this, SIGNAL( contextMenu( TDEListView *, TQListViewItem *, const TQPoint & ) ), this, SLOT( showBibtexListContextMenu( TDEListView *, TQListViewItem *, const TQPoint & ) ) );
-        connect( this, SIGNAL( doubleClicked( TQListViewItem*, const TQPoint&, int ) ), this, SLOT( slotDoubleClick( TQListViewItem* ) ) );
-        connect( this, SIGNAL( dropped( TQDropEvent*, TQListViewItem* ) ), this, SLOT( slotDropped( TQDropEvent*, TQListViewItem* ) ) );
+        connect( header(), TQ_SIGNAL( clicked( int ) ), this, TQ_SLOT( setSortingColumn( int ) ) );
+        connect( this, TQ_SIGNAL( contextMenu( TDEListView *, TQListViewItem *, const TQPoint & ) ), this, TQ_SLOT( showBibtexListContextMenu( TDEListView *, TQListViewItem *, const TQPoint & ) ) );
+        connect( this, TQ_SIGNAL( doubleClicked( TQListViewItem*, const TQPoint&, int ) ), this, TQ_SLOT( slotDoubleClick( TQListViewItem* ) ) );
+        connect( this, TQ_SIGNAL( dropped( TQDropEvent*, TQListViewItem* ) ), this, TQ_SLOT( slotDropped( TQDropEvent*, TQListViewItem* ) ) );
     }
 
     DocumentListView::~DocumentListView()
@@ -185,7 +185,7 @@ namespace KBibTeX
         m_unreadItems.append( after );
 
         emit modified();
-        TQTimer::singleShot( 3500, this, SLOT( makeNewItemsUnread() ) );
+        TQTimer::singleShot( 3500, this, TQ_SLOT( makeNewItemsUnread() ) );
 
         return after;
     }
@@ -227,8 +227,8 @@ namespace KBibTeX
 
     void DocumentListView::deferredInitialization()
     {
-        connect( header(), SIGNAL( sizeChange( int, int, int ) ), this, SLOT( saveColumnWidths() ) );
-        connect( header(), SIGNAL( indexChange( int, int, int ) ), this, SLOT( saveColumnIndex() ) );
+        connect( header(), TQ_SIGNAL( sizeChange( int, int, int ) ), this, TQ_SLOT( saveColumnWidths() ) );
+        connect( header(), TQ_SIGNAL( indexChange( int, int, int ) ), this, TQ_SLOT( saveColumnIndex() ) );
     }
 
     void DocumentListView::restoreState()
@@ -252,7 +252,7 @@ namespace KBibTeX
             m_headerMenu = actionMenu->popupMenu();
             m_headerMenu->insertTitle( i18n( "Show Columns" ) );
             m_headerMenu->setCheckable( TRUE );
-            connect( m_headerMenu, SIGNAL( activated( int ) ), this, SLOT( activateShowColumnMenu( int ) ) );
+            connect( m_headerMenu, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( activateShowColumnMenu( int ) ) );
 
             Settings * settings = Settings::self( m_bibtexFile );
 
