@@ -143,19 +143,19 @@ namespace KBibTeX
         m_sourceView->setFont( TDEGlobalSettings::fixedFont() );
 
         // Setup actions
-        connect( m_searchBar, SIGNAL( onlineSearch() ), this, SLOT( onlineSearch() ) );
-        connect( m_searchBar, SIGNAL( doSearch( const TQString&, BibTeX::Element::FilterType, BibTeX::EntryField::FieldType ) ), m_listViewElements, SLOT( filter( const TQString&, BibTeX::Element::FilterType, BibTeX::EntryField::FieldType ) ) );
-        connect( m_listViewElements, SIGNAL( executed( DocumentListViewItem* ) ), this, SLOT( executeElement( DocumentListViewItem* ) ) );
-        connect( m_listViewElements, SIGNAL( selectionChanged() ), this, SLOT( slotSelectionChanged() ) );
-        connect( m_listViewElements, SIGNAL( currentChanged( TQListViewItem* ) ), this, SLOT( slotPreviewElement( TQListViewItem* ) ) );
-        connect( m_listViewElements, SIGNAL( clicked( TQListViewItem* ) ), this, SLOT( slotPreviewElement( TQListViewItem* ) ) );
-        connect( this, SIGNAL( currentChanged( TQWidget * ) ), this, SLOT( slotTabChanged( TQWidget* ) ) );
-        connect( m_sourceView, SIGNAL( modified() ), this, SLOT( slotModified() ) );
-        connect( m_listViewElements, SIGNAL( modified() ), this, SLOT( slotModified() ) );
-        connect( m_sideBar, SIGNAL( valueRenamed() ), this, SLOT( slotModified() ) );
-        connect( m_sideBar, SIGNAL( valueRenamed() ), this, SLOT( refreshBibTeXFile() ) );
-        connect( m_sideBar, SIGNAL( selected( const TQString&, BibTeX::Element::FilterType, BibTeX::EntryField::FieldType ) ), m_searchBar, SLOT( setSearch( const TQString&, BibTeX::Element::FilterType, BibTeX::EntryField::FieldType ) ) );
-        connect( &m_dirWatch, SIGNAL( dirty( const TQString& ) ), this, SLOT( slotFileGotDirty( const TQString & ) ) );
+        connect( m_searchBar, TQ_SIGNAL( onlineSearch() ), this, TQ_SLOT( onlineSearch() ) );
+        connect( m_searchBar, TQ_SIGNAL( doSearch( const TQString&, BibTeX::Element::FilterType, BibTeX::EntryField::FieldType ) ), m_listViewElements, TQ_SLOT( filter( const TQString&, BibTeX::Element::FilterType, BibTeX::EntryField::FieldType ) ) );
+        connect( m_listViewElements, TQ_SIGNAL( executed( DocumentListViewItem* ) ), this, TQ_SLOT( executeElement( DocumentListViewItem* ) ) );
+        connect( m_listViewElements, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( slotSelectionChanged() ) );
+        connect( m_listViewElements, TQ_SIGNAL( currentChanged( TQListViewItem* ) ), this, TQ_SLOT( slotPreviewElement( TQListViewItem* ) ) );
+        connect( m_listViewElements, TQ_SIGNAL( clicked( TQListViewItem* ) ), this, TQ_SLOT( slotPreviewElement( TQListViewItem* ) ) );
+        connect( this, TQ_SIGNAL( currentChanged( TQWidget * ) ), this, TQ_SLOT( slotTabChanged( TQWidget* ) ) );
+        connect( m_sourceView, TQ_SIGNAL( modified() ), this, TQ_SLOT( slotModified() ) );
+        connect( m_listViewElements, TQ_SIGNAL( modified() ), this, TQ_SLOT( slotModified() ) );
+        connect( m_sideBar, TQ_SIGNAL( valueRenamed() ), this, TQ_SLOT( slotModified() ) );
+        connect( m_sideBar, TQ_SIGNAL( valueRenamed() ), this, TQ_SLOT( refreshBibTeXFile() ) );
+        connect( m_sideBar, TQ_SIGNAL( selected( const TQString&, BibTeX::Element::FilterType, BibTeX::EntryField::FieldType ) ), m_searchBar, TQ_SLOT( setSearch( const TQString&, BibTeX::Element::FilterType, BibTeX::EntryField::FieldType ) ) );
+        connect( &m_dirWatch, TQ_SIGNAL( dirty( const TQString& ) ), this, TQ_SLOT( slotFileGotDirty( const TQString & ) ) );
     }
 
 
@@ -626,10 +626,10 @@ namespace KBibTeX
 
         m_viewDocumentActionMenu = dynamic_cast<TDEActionMenu*>( client->action( "view_document" ) );
         if ( m_viewDocumentActionMenu != NULL )
-            connect( m_viewDocumentActionMenu->popupMenu(), SIGNAL( activated( int ) ), this, SLOT( slotViewDocument( int ) ) );
+            connect( m_viewDocumentActionMenu->popupMenu(), TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotViewDocument( int ) ) );
         m_assignKeywordsActionMenu = dynamic_cast<TDEActionMenu*>( client->action( "assign_keywords" ) );
         if ( m_assignKeywordsActionMenu != NULL )
-            connect( m_assignKeywordsActionMenu->popupMenu(), SIGNAL( activated( int ) ), this, SLOT( slotAssignKeywords( int ) ) );
+            connect( m_assignKeywordsActionMenu->popupMenu(), TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotAssignKeywords( int ) ) );
 
         m_actionEditCut = client->action( "edit_cut" );
         m_actionEditCopy = client->action( "edit_copy" );
@@ -789,7 +789,7 @@ namespace KBibTeX
             int maxCountPerSubMenu = ( int )sqrt( allKeywords.count() ) + 1;
             int countPerSubMenu = 0;
             TDEPopupMenu *subMenu = new TDEPopupMenu( popup );
-            connect( subMenu, SIGNAL( activated( int ) ), this, SLOT( slotAssignKeywords( int ) ) );
+            connect( subMenu, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotAssignKeywords( int ) ) );
             TQString startWord, endWord;
             for ( TQStringList::Iterator it = allKeywords.begin(); it != allKeywords.end(); ++it )
             {
@@ -805,7 +805,7 @@ namespace KBibTeX
                 {
                     popup->insertItem( TQString( i18n( "%1 ... %2" ) ).arg( startWord ).arg( endWord ), subMenu );
                     subMenu = new TDEPopupMenu( popup );
-                    connect( subMenu, SIGNAL( activated( int ) ), this, SLOT( slotAssignKeywords( int ) ) );
+                    connect( subMenu, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotAssignKeywords( int ) ) );
                     countPerSubMenu = 0;
                 }
             }
@@ -833,7 +833,7 @@ namespace KBibTeX
         container->setFocusPolicy( TQWidget::ClickFocus );
         popup->insertItem( container );
 
-        connect( m_lineEditNewKeyword, SIGNAL( returnPressed() ), this, SLOT( slotAddKeyword() ) );
+        connect( m_lineEditNewKeyword, TQ_SIGNAL( returnPressed() ), this, TQ_SLOT( slotAddKeyword() ) );
     }
 
     void DocumentWidget::deferredInitialization()
@@ -1141,15 +1141,15 @@ namespace KBibTeX
     {
         m_progressDialog = new TQProgressDialog( this );
         m_progressDialog->setLabelText( label );
-        connect( progressFrom, SIGNAL( progress( int, int ) ), this, SLOT( slotShowProgress( int, int ) ) );
-        connect( m_progressDialog, SIGNAL( canceled() ), progressFrom, SLOT( cancel( ) ) );
+        connect( progressFrom, TQ_SIGNAL( progress( int, int ) ), this, TQ_SLOT( slotShowProgress( int, int ) ) );
+        connect( m_progressDialog, TQ_SIGNAL( canceled() ), progressFrom, TQ_SLOT( cancel( ) ) );
         TQApplication::setOverrideCursor( TQt::waitCursor );
     }
 
     void DocumentWidget::endProgress( TQObject * progressFrom )
     {
-        disconnect( progressFrom, SIGNAL( progress( int, int ) ), this, SLOT( slotShowProgress( int, int ) ) );
-        disconnect( m_progressDialog, SIGNAL( canceled() ), progressFrom, SLOT( cancel( ) ) );
+        disconnect( progressFrom, TQ_SIGNAL( progress( int, int ) ), this, TQ_SLOT( slotShowProgress( int, int ) ) );
+        disconnect( m_progressDialog, TQ_SIGNAL( canceled() ), progressFrom, TQ_SLOT( cancel( ) ) );
         delete m_progressDialog;
         m_progressDialog = NULL;
         TQApplication::restoreOverrideCursor();
@@ -1545,7 +1545,7 @@ namespace KBibTeX
         if ( path == m_filename )
         {
             m_dirWatch.removeFile( m_filename );
-            TQTimer::singleShot( 100, this, SLOT( slotRefreshDirtyFile( ) ) );
+            TQTimer::singleShot( 100, this, TQ_SLOT( slotRefreshDirtyFile( ) ) );
         }
     }
 
