@@ -85,8 +85,8 @@ namespace KBibTeX
         m_pushButtonForceDefaultIdSuggestion->setEnabled( !m_isReadOnly && m_defaultIdSuggestionAvailable );
         m_pushButtonIdSuggestions->setEnabled( !m_isReadOnly );
 
-        connect( m_wqa, SIGNAL( foundEntry( BibTeX::Entry*, bool ) ), this, SLOT( useExternalEntry( BibTeX::Entry*, bool ) ) );
-        connect( m_wqa, SIGNAL( endSearch( WebQuery::Status ) ), this, SLOT( endExternalSearch( WebQuery::Status ) ) );
+        connect( m_wqa, TQ_SIGNAL( foundEntry( BibTeX::Entry*, bool ) ), this, TQ_SLOT( useExternalEntry( BibTeX::Entry*, bool ) ) );
+        connect( m_wqa, TQ_SIGNAL( endSearch( WebQuery::Status ) ), this, TQ_SLOT( endExternalSearch( WebQuery::Status ) ) );
     }
 
     EntryWidget::EntryWidget( BibTeX::Entry *entry, BibTeX::File *bibtexfile, bool isReadOnly, bool isNew, TQDialog *parent, const char *name )
@@ -102,8 +102,8 @@ namespace KBibTeX
 
         reset();
 
-        connect( m_wqa, SIGNAL( foundEntry( BibTeX::Entry*, bool ) ), this, SLOT( useExternalEntry( BibTeX::Entry*, bool ) ) );
-        connect( m_wqa, SIGNAL( endSearch( WebQuery::Status ) ), this, SLOT( endExternalSearch( WebQuery::Status ) ) );
+        connect( m_wqa, TQ_SIGNAL( foundEntry( BibTeX::Entry*, bool ) ), this, TQ_SLOT( useExternalEntry( BibTeX::Entry*, bool ) ) );
+        connect( m_wqa, TQ_SIGNAL( endSearch( WebQuery::Status ) ), this, TQ_SLOT( endExternalSearch( WebQuery::Status ) ) );
     }
 
     EntryWidget::~EntryWidget()
@@ -331,7 +331,7 @@ namespace KBibTeX
 
         m_pushButtonIdSuggestions = new TQPushButton( TQIconSet( BarIcon( "wizard" ) ), "", this, "m_pushButtonIdSuggestions" );
         m_menuIdSuggestions = new TQPopupMenu( m_pushButtonIdSuggestions );
-        connect( m_menuIdSuggestions, SIGNAL( activated( int ) ), this, SLOT( insertIdSuggestion( int ) ) );
+        connect( m_menuIdSuggestions, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( insertIdSuggestion( int ) ) );
         m_pushButtonIdSuggestions->setPopup( m_menuIdSuggestions );
         layout->addWidget( m_pushButtonIdSuggestions, 0, 4 );
 
@@ -352,7 +352,7 @@ namespace KBibTeX
 
         m_pushButtonRefetch = new TQPushButton( TDEGlobal::iconLoader() ->loadIconSet( "reload", TDEIcon::Small ), i18n( "Refetch" ), this );
         layout->addWidget( m_pushButtonRefetch, 2, 5 );
-        connect( m_pushButtonRefetch, SIGNAL( clicked() ), this, SLOT( refreshFromURL() ) );
+        connect( m_pushButtonRefetch, TQ_SIGNAL( clicked() ), this, TQ_SLOT( refreshFromURL() ) );
 
         if ( showWarnings )
         {
@@ -361,21 +361,21 @@ namespace KBibTeX
             m_listViewWarnings->addColumn( i18n( "Message" ) );
             m_listViewWarnings->setAllColumnsShowFocus( true );
             layout->addMultiCellWidget( m_listViewWarnings, 3, 3, 0, 5 );
-            connect( m_listViewWarnings, SIGNAL( doubleClicked( TQListViewItem*, const TQPoint&, int ) ), this, SLOT( warningsExecute( TQListViewItem* ) ) );
+            connect( m_listViewWarnings, TQ_SIGNAL( doubleClicked( TQListViewItem*, const TQPoint&, int ) ), this, TQ_SLOT( warningsExecute( TQListViewItem* ) ) );
         }
         else
             m_listViewWarnings = NULL;
 
-        connect( m_checkBoxEnableAll, SIGNAL( toggled( bool ) ), this, SLOT( slotEnableAllFields( ) ) );
-        connect( m_comboBoxEntryType, SIGNAL( activated( int ) ), this, SLOT( slotEntryTypeChanged( ) ) );
-        connect( m_pushButtonForceDefaultIdSuggestion, SIGNAL( toggled( bool ) ), this, SLOT( slotForceDefaultIdSuggestion() ) );
-        connect( m_comboBoxEntryType, SIGNAL( textChanged( const TQString & ) ), this, SLOT( slotEntryTypeChanged() ) );
-        connect( m_tabWidget, SIGNAL( currentChanged( TQWidget* ) ), this, SLOT( slotCurrentPageChanged( TQWidget* ) ) );
-        connect( parent, SIGNAL( okClicked() ), this, SLOT( apply() ) );
-        connect( m_menuIdSuggestions, SIGNAL( aboutToShow() ), this, SLOT( updateIdSuggestionsMenu() ) );
+        connect( m_checkBoxEnableAll, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( slotEnableAllFields( ) ) );
+        connect( m_comboBoxEntryType, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotEntryTypeChanged( ) ) );
+        connect( m_pushButtonForceDefaultIdSuggestion, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( slotForceDefaultIdSuggestion() ) );
+        connect( m_comboBoxEntryType, TQ_SIGNAL( textChanged( const TQString & ) ), this, TQ_SLOT( slotEntryTypeChanged() ) );
+        connect( m_tabWidget, TQ_SIGNAL( currentChanged( TQWidget* ) ), this, TQ_SLOT( slotCurrentPageChanged( TQWidget* ) ) );
+        connect( parent, TQ_SIGNAL( okClicked() ), this, TQ_SLOT( apply() ) );
+        connect( m_menuIdSuggestions, TQ_SIGNAL( aboutToShow() ), this, TQ_SLOT( updateIdSuggestionsMenu() ) );
 
         m_updateWarningsTimer = new TQTimer( this );
-        connect( m_updateWarningsTimer, SIGNAL( timeout() ), this, SLOT( updateWarnings() ) );
+        connect( m_updateWarningsTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( updateWarnings() ) );
         if ( !m_isReadOnly )
             m_updateWarningsTimer->start( 500 );
     }
@@ -548,7 +548,7 @@ namespace KBibTeX
         int scnum = TQApplication::desktop()->screenNumber( parentWidget() );
         TQRect desk = TQApplication::desktop()->screenGeometry( scnum );
         int w, h;
-#if defined Q_WS_X11
+#if defined TQ_WS_X11
         // save maximalization as desktop size + 1 in that direction
         KWin::WindowInfo info = KWin::windowInfo( m_dlgParent->winId(), NET::WMState );
         w = info.state() & NET::MaxHoriz ? desk.width() + 1 : m_dlgParent->width();
@@ -600,7 +600,7 @@ namespace KBibTeX
         }
         if ( !size.isEmpty() )
         {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
             int state = ( size.width() > desk.width() ? NET::MaxHoriz : 0 )
                         | ( size.height() > desk.height() ? NET::MaxVert : 0 );
             if (( state & NET::Max ) == NET::Max )
