@@ -17,9 +17,9 @@
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
-#include <ntqlayout.h>
-#include <ntqlabel.h>
-#include <ntqtooltip.h>
+#include <tqlayout.h>
+#include <tqlabel.h>
+#include <tqtooltip.h>
 
 #include <kpushbutton.h>
 #include <kdialog.h>
@@ -30,8 +30,8 @@
 #include <kiconloader.h>
 #include <tdepopupmenu.h>
 
-#include <fieldlineedit.h>
-#include <settings.h>
+#include "fieldlineedit.h"
+#include "settings.h"
 #include "entrywidgetexternal.h"
 
 namespace KBibTeX
@@ -89,9 +89,9 @@ namespace KBibTeX
 
     void EntryWidgetExternal::reset( BibTeX::Entry *entry )
     {
-        disconnect( m_fieldLineEditURL, SIGNAL( textChanged() ), this, SLOT( updateGUI() ) );
-        disconnect( m_fieldLineEditDoi, SIGNAL( textChanged() ), this, SLOT( updateGUI() ) );
-        disconnect( m_fieldLineEditLocalFile, SIGNAL( textChanged() ), this, SLOT( updateGUI() ) );
+        disconnect( m_fieldLineEditURL, TQ_SIGNAL( textChanged() ), this, TQ_SLOT( updateGUI() ) );
+        disconnect( m_fieldLineEditDoi, TQ_SIGNAL( textChanged() ), this, TQ_SLOT( updateGUI() ) );
+        disconnect( m_fieldLineEditLocalFile, TQ_SIGNAL( textChanged() ), this, TQ_SLOT( updateGUI() ) );
 
 
         BibTeX::EntryField * field = entry->getField( BibTeX::EntryField::ftURL );
@@ -105,9 +105,9 @@ namespace KBibTeX
 
         updateGUI();
 
-        connect( m_fieldLineEditURL, SIGNAL( textChanged() ), this, SLOT( updateGUI() ) );
-        connect( m_fieldLineEditDoi, SIGNAL( textChanged() ), this, SLOT( updateGUI() ) );
-        connect( m_fieldLineEditLocalFile, SIGNAL( textChanged() ), this, SLOT( updateGUI() ) );
+        connect( m_fieldLineEditURL, TQ_SIGNAL( textChanged() ), this, TQ_SLOT( updateGUI() ) );
+        connect( m_fieldLineEditDoi, TQ_SIGNAL( textChanged() ), this, TQ_SLOT( updateGUI() ) );
+        connect( m_fieldLineEditLocalFile, TQ_SIGNAL( textChanged() ), this, TQ_SLOT( updateGUI() ) );
     }
 
     void EntryWidgetExternal::updateWarnings( BibTeX::Entry::EntryType entryType, TQListView *listViewWarnings )
@@ -226,14 +226,14 @@ namespace KBibTeX
         m_fieldLineEditURL->setFieldType( BibTeX::EntryField::ftURL );
         gridLayout->addWidget( m_fieldLineEditURL, 0, 1 );
         label->setBuddy( m_fieldLineEditURL );
-        connect( m_fieldLineEditURL, SIGNAL( textChanged() ), this, SLOT( updateGUI() ) );
+        connect( m_fieldLineEditURL, TQ_SIGNAL( textChanged() ), this, TQ_SLOT( updateGUI() ) );
 
         m_pushButtonOpenURL = new KPushButton( this );
         gridLayout->addWidget( m_pushButtonOpenURL, 0, 2 );
         m_pushButtonOpenURL->setIconSet( TQIconSet( SmallIcon( "document-open" ) ) );
         m_pushButtonOpenURL->setSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum );
         TQToolTip::add( m_pushButtonOpenURL, TQString( i18n( "Open %1" ) ).arg( i18n( "URL" ) ) );
-        connect( m_pushButtonOpenURL, SIGNAL( clicked() ), this, SLOT( openURL() ) );
+        connect( m_pushButtonOpenURL, TQ_SIGNAL( clicked() ), this, TQ_SLOT( openURL() ) );
 
         KURLLabel *urllabel = new KURLLabel( "http://www.doi.org/", TQString( "%1:" ).arg( i18n( "DOI" ) ), this );
         TQToolTip::add( urllabel, i18n( "Digital Object Identifier" ) );
@@ -243,15 +243,15 @@ namespace KBibTeX
         m_fieldLineEditDoi->setFieldType( BibTeX::EntryField::ftDoi );
         gridLayout->addWidget( m_fieldLineEditDoi, 1, 1 );
         urllabel->setBuddy( m_fieldLineEditDoi );
-        connect( m_fieldLineEditDoi, SIGNAL( textChanged() ), this, SLOT( updateGUI() ) );
-        connect( urllabel, SIGNAL( leftClickedURL( const TQString& ) ), this, SLOT( openURL( const TQString& ) ) );
+        connect( m_fieldLineEditDoi, TQ_SIGNAL( textChanged() ), this, TQ_SLOT( updateGUI() ) );
+        connect( urllabel, TQ_SIGNAL( leftClickedURL( const TQString& ) ), this, TQ_SLOT( openURL( const TQString& ) ) );
 
         m_pushButtonOpenDoi = new KPushButton( this );
         gridLayout->addWidget( m_pushButtonOpenDoi, 1, 2 );
         m_pushButtonOpenDoi->setIconSet( TQIconSet( SmallIcon( "document-open" ) ) );
         m_pushButtonOpenDoi->setSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum );
         TQToolTip::add( m_pushButtonOpenDoi, i18n( "Open DOI" ) );
-        connect( m_pushButtonOpenDoi, SIGNAL( clicked() ), this, SLOT( openDoi() ) );
+        connect( m_pushButtonOpenDoi, TQ_SIGNAL( clicked() ), this, TQ_SLOT( openDoi() ) );
 
         label = new TQLabel( TQString( "%1:" ).arg( i18n( "Local File" ) ), this );
         gridLayout->addWidget( label, 2, 0 );
@@ -259,14 +259,14 @@ namespace KBibTeX
         m_fieldLineEditLocalFile->setFieldType( BibTeX::EntryField::ftLocalFile );
         gridLayout->addWidget( m_fieldLineEditLocalFile, 2, 1 );
         label->setBuddy( m_fieldLineEditLocalFile );
-        connect( m_fieldLineEditLocalFile, SIGNAL( textChanged() ), this, SLOT( updateGUI() ) );
+        connect( m_fieldLineEditLocalFile, TQ_SIGNAL( textChanged() ), this, TQ_SLOT( updateGUI() ) );
 
         m_pushButtonOpenLocalFile = new KPushButton( this );
         gridLayout->addWidget( m_pushButtonOpenLocalFile, 2, 2 );
         m_pushButtonOpenLocalFile->setIconSet( TQIconSet( SmallIcon( "document-open" ) ) );
         m_pushButtonOpenLocalFile->setSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum );
         TQToolTip::add( m_pushButtonOpenLocalFile, TQString( i18n( "Open %1" ) ).arg( i18n( "Local File" ) ) );
-        connect( m_pushButtonOpenLocalFile, SIGNAL( clicked() ), this, SLOT( openLocalFile() ) );
+        connect( m_pushButtonOpenLocalFile, TQ_SIGNAL( clicked() ), this, TQ_SLOT( openLocalFile() ) );
 
         TQWidget *container = new TQWidget( this );
         TQHBoxLayout *containerLayout = new TQHBoxLayout( container );
@@ -291,7 +291,7 @@ namespace KBibTeX
                 menu->insertItem( TQIconSet( SmallIcon( "folder" ) ), *it, i );
         }
         m_pushButtonBrowseLocalFile->setPopup( menu );
-        connect( menu, SIGNAL( activated( int ) ), this, SLOT( browseLocalFile( int ) ) );
+        connect( menu, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( browseLocalFile( int ) ) );
     }
 }
 #include "entrywidgetexternal.moc"
