@@ -17,21 +17,21 @@
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
-#include <ntqlayout.h>
-#include <ntqlabel.h>
-#include <ntqregexp.h>
-#include <ntqpushbutton.h>
-#include <ntqpopupmenu.h>
-#include <ntqtooltip.h>
+#include <tqlayout.h>
+#include <tqlabel.h>
+#include <tqregexp.h>
+#include <tqpushbutton.h>
+#include <tqpopupmenu.h>
+#include <tqtooltip.h>
 
 #include <kurl.h>
 #include <kiconloader.h>
 #include <kdialog.h>
 #include <tdelocale.h>
 
-#include <settings.h>
-#include <fieldlineedit.h>
-#include <entrywidgetwarningsitem.h>
+#include "settings.h"
+#include "fieldlineedit.h"
+#include "entrywidgetwarningsitem.h"
 #include "entrywidgetpublication.h"
 
 namespace KBibTeX
@@ -471,7 +471,7 @@ namespace KBibTeX
         m_fieldLineEditCrossRef->setFieldType( BibTeX::EntryField::ftCrossRef );
         label->setBuddy( m_fieldLineEditCrossRef );
         gridLayout->addWidget( m_fieldLineEditCrossRef, 8, 1 );
-        connect( m_fieldLineEditCrossRef, SIGNAL( textChanged() ), this, SLOT( slotSetCrossRefEntry() ) );
+        connect( m_fieldLineEditCrossRef, TQ_SIGNAL( textChanged() ), this, TQ_SLOT( slotSetCrossRefEntry() ) );
 
         label = new TQLabel( TQString( "%1:" ).arg( i18n( "Organization" ) ), this );
         gridLayout->addWidget( label, 0, 3 );
@@ -528,7 +528,7 @@ namespace KBibTeX
         m_fieldLineEditISBN ->setFieldType( BibTeX::EntryField::ftISBN );
         label->setBuddy( m_fieldLineEditISBN );
         innerLayout->addWidget( m_fieldLineEditISBN );
-        connect( m_pushButtonISBN, SIGNAL( clicked() ), this, SLOT( slotOpenISBN() ) );
+        connect( m_pushButtonISBN, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotOpenISBN() ) );
 
         label = new TQLabel( TQString( "%1:" ).arg( i18n( "ISSN" ) ), this );
         gridLayout->addWidget( label, 7, 3 );
@@ -548,7 +548,7 @@ namespace KBibTeX
         for ( int i = 0; i < 12; i++ )
             menuMonths->insertItem( BibTeX::Months[ i ], i );
         m_pushButtonMonths->setPopup( menuMonths );
-        connect( menuMonths, SIGNAL( activated( int ) ), this, SLOT( slotSetMonth( int ) ) );
+        connect( menuMonths, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotSetMonth( int ) ) );
     }
 
     TQString EntryWidgetPublication::isbn() const
