@@ -227,7 +227,7 @@ namespace KBibTeX
         m_pushButtonString->setToggleButton( TRUE );
         TQToolTip::add( m_pushButtonString, TQString( i18n( "Set '%1' to be a string key" ) ).arg( m_caption ) );
         m_pushButtonString->setEnabled( !m_isReadOnly );
-        connect( m_pushButtonString, SIGNAL( clicked() ), this, SLOT( slotStringToggled() ) );
+        connect( m_pushButtonString, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotStringToggled() ) );
 
         if ( subname != NULL )
         {
@@ -238,7 +238,7 @@ namespace KBibTeX
         m_pushButtonComplex->setIconSet( TQIconSet( SmallIcon( "format-justify-left" ) ) );
         m_pushButtonComplex->setSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum );
         TQToolTip::add( m_pushButtonComplex, TQString( i18n( "Edit '%1' as a concatenated value" ) ).arg( m_caption ) );
-        connect( m_pushButtonComplex, SIGNAL( clicked() ), this, SLOT( slotComplexClicked() ) );
+        connect( m_pushButtonComplex, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotComplexClicked() ) );
 
         TQGridLayout * layout = NULL;
         switch ( m_inputType )
@@ -353,15 +353,15 @@ namespace KBibTeX
         {
         case itSingleLine:
             if ( enabled )
-                connect( m_lineEdit, SIGNAL( textChanged( const TQString& ) ), this, SLOT( slotTextChanged( ) ) );
+                connect( m_lineEdit, TQ_SIGNAL( textChanged( const TQString& ) ), this, TQ_SLOT( slotTextChanged( ) ) );
             else
-                disconnect( m_lineEdit, SIGNAL( textChanged( const TQString& ) ), this, SLOT( slotTextChanged( ) ) );
+                disconnect( m_lineEdit, TQ_SIGNAL( textChanged( const TQString& ) ), this, TQ_SLOT( slotTextChanged( ) ) );
             break;
         case itMultiLine:
             if ( enabled )
-                connect( m_textEdit, SIGNAL( textChanged( ) ), this, SLOT( slotTextChanged( ) ) );
+                connect( m_textEdit, TQ_SIGNAL( textChanged( ) ), this, TQ_SLOT( slotTextChanged( ) ) );
             else
-                disconnect( m_textEdit, SIGNAL( textChanged( ) ), this, SLOT( slotTextChanged( ) ) );
+                disconnect( m_textEdit, TQ_SIGNAL( textChanged( ) ), this, TQ_SLOT( slotTextChanged( ) ) );
             break;
         }
     }
