@@ -34,7 +34,7 @@ namespace KBibTeX
 {
     class FieldLineEdit : public TQWidget
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         enum InputType {itSingleLine, itMultiLine};
         enum ErrorType {etNoError, etInvalidStringKey};
