@@ -748,7 +748,7 @@ TDEInstance* KBibTeXPartFactory::instance()
 
 extern "C"
 {
-    KDE_EXPORT void* init_libkbibtexpart()
+    TDE_EXPORT void* init_libkbibtexpart()
     {
         return new KBibTeXPartFactory;
     }
