@@ -42,7 +42,7 @@ namespace KBibTeX
             : TQWidget( parent, name )
     {
         m_timerInput = new TQTimer( this );
-        connect( m_timerInput, SIGNAL( timeout() ), SLOT( slotTimeout() ) );
+        connect( m_timerInput, TQ_SIGNAL( timeout() ), TQ_SLOT( slotTimeout() ) );
 
         setupGUI();
     }
@@ -95,7 +95,7 @@ namespace KBibTeX
         m_pushButtonSearchOnlineDatabases->setIconSet( TQIconSet( BarIcon( "network" ) ) );
         layout->addWidget( m_pushButtonSearchOnlineDatabases );
         TQToolTip::add( m_pushButtonSearchOnlineDatabases, i18n( "Add a new BibTeX entry from an online database" ) );
-        connect( m_pushButtonSearchOnlineDatabases, SIGNAL( clicked() ), this, SIGNAL( onlineSearch() ) );
+        connect( m_pushButtonSearchOnlineDatabases, TQ_SIGNAL( clicked() ), this, TQ_SIGNAL( onlineSearch() ) );
 
         layout->insertSpacing( 2, KDialog::spacingHint() );
 
@@ -137,14 +137,14 @@ namespace KBibTeX
             m_comboboxRestrictTo->insertItem( Settings::fieldTypeToI18NString( fieldType ) );
         }
 
-        connect( m_comboboxFilter->lineEdit(), SIGNAL( textChanged( const TQString & ) ), this, SLOT( slotKeyPressed() ) );
-        connect( m_comboboxFilter, SIGNAL( activated( const TQString& ) ), m_comboboxFilter, SLOT( addToHistory( const TQString& ) ) );
-        connect( m_pushButtonClearSearchText, SIGNAL( clicked() ), this, SLOT( slotClear() ) );
-        connect( m_comboboxFilterType, SIGNAL( textChanged( const TQString& ) ), this, SLOT( slotAnnounceDoSearch() ) );
-        connect( m_comboboxFilter, SIGNAL( textChanged( const TQString& ) ), this, SLOT( slotAnnounceDoSearch() ) );
-        connect( m_comboboxFilter->lineEdit(), SIGNAL( returnPressed() ), this, SLOT( slotAnnounceDoSearch() ) );
-        connect( m_comboboxFilterType, SIGNAL( activated( int ) ), this, SLOT( slotTimeout() ) );
-        connect( m_comboboxRestrictTo, SIGNAL( activated( int ) ), this, SLOT( slotTimeout() ) );
+        connect( m_comboboxFilter->lineEdit(), TQ_SIGNAL( textChanged( const TQString & ) ), this, TQ_SLOT( slotKeyPressed() ) );
+        connect( m_comboboxFilter, TQ_SIGNAL( activated( const TQString& ) ), m_comboboxFilter, TQ_SLOT( addToHistory( const TQString& ) ) );
+        connect( m_pushButtonClearSearchText, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotClear() ) );
+        connect( m_comboboxFilterType, TQ_SIGNAL( textChanged( const TQString& ) ), this, TQ_SLOT( slotAnnounceDoSearch() ) );
+        connect( m_comboboxFilter, TQ_SIGNAL( textChanged( const TQString& ) ), this, TQ_SLOT( slotAnnounceDoSearch() ) );
+        connect( m_comboboxFilter->lineEdit(), TQ_SIGNAL( returnPressed() ), this, TQ_SLOT( slotAnnounceDoSearch() ) );
+        connect( m_comboboxFilterType, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotTimeout() ) );
+        connect( m_comboboxRestrictTo, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotTimeout() ) );
 
         setSizePolicy( TQSizePolicy::MinimumExpanding, TQSizePolicy::Preferred );
     }
