@@ -84,11 +84,11 @@ namespace KBibTeX
         layout->setRowStretch( 4, 1 );
         layout->setColStretch( 0, 1 );
 
-        connect( m_urlRequesterNewPath, SIGNAL( textChanged( const TQString& ) ), this, SLOT( slotTextChanged( const TQString& ) ) );
-        connect( m_urlRequesterNewPath, SIGNAL( urlSelected( const TQString& ) ), this, SLOT( slotTextChanged( const TQString& ) ) );
-        connect( m_pushButtonAddDir, SIGNAL( clicked() ), this, SLOT( slotAddDir() ) );
-        connect( m_listViewPathList, SIGNAL( selectionChanged() ), this, SLOT( slotSelectionChanged() ) );
-        connect( m_pushButtonDelDir, SIGNAL( clicked() ), this, SLOT( slotDelDir() ) );
+        connect( m_urlRequesterNewPath, TQ_SIGNAL( textChanged( const TQString& ) ), this, TQ_SLOT( slotTextChanged( const TQString& ) ) );
+        connect( m_urlRequesterNewPath, TQ_SIGNAL( urlSelected( const TQString& ) ), this, TQ_SLOT( slotTextChanged( const TQString& ) ) );
+        connect( m_pushButtonAddDir, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotAddDir() ) );
+        connect( m_listViewPathList, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( slotSelectionChanged() ) );
+        connect( m_pushButtonDelDir, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotDelDir() ) );
 
         for ( TQStringList::Iterator it = pathList.begin(); it != pathList.end(); ++it )
             new TQListViewItem( m_listViewPathList, *it );
@@ -99,8 +99,8 @@ namespace KBibTeX
         KDialogBase *dlg = new KDialogBase( parent, "SettingsEditingPathsDialog", true, i18n( "Edit Document Search Paths" ), KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, false );
         SettingsEditingPaths *sep = new SettingsEditingPaths( pathList, dlg, "SettingsEditingPaths" );
         dlg->setMainWidget( sep );
-        connect( dlg, SIGNAL( apply() ), sep, SLOT( slotApply() ) );
-        connect( dlg, SIGNAL( okClicked() ), sep, SLOT( slotApply() ) );
+        connect( dlg, TQ_SIGNAL( apply() ), sep, TQ_SLOT( slotApply() ) );
+        connect( dlg, TQ_SIGNAL( okClicked() ), sep, TQ_SLOT( slotApply() ) );
 
         bool result = dlg->exec() == TQDialog::Accepted;
         delete dlg;
@@ -229,16 +229,16 @@ namespace KBibTeX
 
         layout->addStretch();
 
-        connect( m_checkBoxSearchBarClearField, SIGNAL( toggled( bool ) ), this, SLOT( slotConfigChanged() ) );
-        connect( m_checkBoxEnableAllFields, SIGNAL( toggled( bool ) ), this, SLOT( slotConfigChanged() ) );
-        connect( m_comboBoxDoubleClickAction, SIGNAL( activated( int ) ), this, SLOT( slotConfigChanged() ) );
-        connect( m_comboBoxDragAction, SIGNAL( activated( int ) ), this, SLOT( slotConfigChanged() ) );
-        connect( m_comboBoxSortingColumn, SIGNAL( activated( int ) ), this, SLOT( slotConfigChanged() ) );
-        connect( m_comboBoxSortingOrder, SIGNAL( activated( int ) ), this, SLOT( slotConfigChanged() ) );
-        connect( m_pushButtonSpecialFont, SIGNAL( clicked() ), this, SLOT( slotSelectSpecialFont() ) );
-        connect( m_checkBoxUseSpecialFont, SIGNAL( toggled( bool ) ), m_pushButtonSpecialFont, SLOT( setEnabled( bool ) ) );
-        connect( m_checkBoxUseSpecialFont, SIGNAL( toggled( bool ) ), this, SLOT( slotConfigChanged() ) );
-        connect( btnSelectDocumentSearchPath, SIGNAL( clicked() ), this, SLOT( slotSelectDocumentSearchPath() ) );
+        connect( m_checkBoxSearchBarClearField, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( slotConfigChanged() ) );
+        connect( m_checkBoxEnableAllFields, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( slotConfigChanged() ) );
+        connect( m_comboBoxDoubleClickAction, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotConfigChanged() ) );
+        connect( m_comboBoxDragAction, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotConfigChanged() ) );
+        connect( m_comboBoxSortingColumn, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotConfigChanged() ) );
+        connect( m_comboBoxSortingOrder, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotConfigChanged() ) );
+        connect( m_pushButtonSpecialFont, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotSelectSpecialFont() ) );
+        connect( m_checkBoxUseSpecialFont, TQ_SIGNAL( toggled( bool ) ), m_pushButtonSpecialFont, TQ_SLOT( setEnabled( bool ) ) );
+        connect( m_checkBoxUseSpecialFont, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( slotConfigChanged() ) );
+        connect( btnSelectDocumentSearchPath, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotSelectDocumentSearchPath() ) );
     }
 
 
