@@ -153,14 +153,14 @@ namespace KBibTeX
         m_pushbuttonReset->setIconSet( TQIconSet( SmallIcon( "reload" ) ) );
         layout->addWidget( m_pushbuttonReset, 4, 1 );
 
-        connect( m_pushbuttonNew, SIGNAL( clicked() ), this, SLOT( slotNew() ) );
-        connect( m_pushbuttonEdit, SIGNAL( clicked() ), this, SLOT( slotEdit() ) );
-        connect( m_listviewSearchURLs, SIGNAL( doubleClicked( TQListViewItem *, const TQPoint &, int ) ), this, SLOT( slotEdit() ) );
-        connect( m_pushbuttonDelete, SIGNAL( clicked() ), this, SLOT( slotDelete() ) );
-        connect( m_pushbuttonReset, SIGNAL( clicked() ), this, SLOT( slotReset() ) );
-        connect( m_listviewSearchURLs, SIGNAL( selectionChanged( TQListViewItem * ) ), this, SLOT( updateGUI() ) );
-        connect( m_listviewSearchURLs, SIGNAL( currentChanged( TQListViewItem * ) ), this, SLOT( updateGUI() ) );
-        connect( m_listviewSearchURLs, SIGNAL( onItem( TQListViewItem * ) ), this, SLOT( updateGUI() ) );
+        connect( m_pushbuttonNew, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotNew() ) );
+        connect( m_pushbuttonEdit, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotEdit() ) );
+        connect( m_listviewSearchURLs, TQ_SIGNAL( doubleClicked( TQListViewItem *, const TQPoint &, int ) ), this, TQ_SLOT( slotEdit() ) );
+        connect( m_pushbuttonDelete, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotDelete() ) );
+        connect( m_pushbuttonReset, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotReset() ) );
+        connect( m_listviewSearchURLs, TQ_SIGNAL( selectionChanged( TQListViewItem * ) ), this, TQ_SLOT( updateGUI() ) );
+        connect( m_listviewSearchURLs, TQ_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQ_SLOT( updateGUI() ) );
+        connect( m_listviewSearchURLs, TQ_SIGNAL( onItem( TQListViewItem * ) ), this, TQ_SLOT( updateGUI() ) );
 
         updateGUI();
     }
