@@ -40,7 +40,7 @@ namespace KBibTeX
 
         ValueWidget* valueWidget = new ValueWidget( fieldType, value, isReadOnly, dlg, "kbibtexvaluewidget" );
         dlg->setMainWidget( valueWidget );
-        connect( dlg, SIGNAL( okClicked() ), valueWidget, SLOT( apply() ) );
+        connect( dlg, TQ_SIGNAL( okClicked() ), valueWidget, TQ_SLOT( apply() ) );
 
         TQDialog::DialogCode result = ( TQDialog::DialogCode )dlg->exec();
         if ( isReadOnly ) result = TQDialog::Rejected;
@@ -214,40 +214,40 @@ namespace KBibTeX
         m_listViewValue->header() ->setClickEnabled( FALSE );
         m_listViewValue->header() ->setStretchEnabled( TRUE, 0 );
         m_listViewValue->setEnabled( !m_isReadOnly );
-        connect( m_listViewValue, SIGNAL( selectionChanged() ), this, SLOT( updateGUI() ) );
-        connect( m_listViewValue, SIGNAL( clicked( TQListViewItem * ) ), this, SLOT( updateGUI() ) );
-        connect( m_listViewValue, SIGNAL( currentChanged( TQListViewItem * ) ), this, SLOT( updateGUI() ) );
+        connect( m_listViewValue, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( updateGUI() ) );
+        connect( m_listViewValue, TQ_SIGNAL( clicked( TQListViewItem * ) ), this, TQ_SLOT( updateGUI() ) );
+        connect( m_listViewValue, TQ_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQ_SLOT( updateGUI() ) );
 
         m_pushButtonAdd = new TQPushButton( i18n( "Add" ), this );
         layout->addWidget( m_pushButtonAdd, 1, 1 );
         m_pushButtonAdd->setIconSet( TQIconSet( SmallIcon( "add" ) ) );
         m_pushButtonAdd->setEnabled( !m_isReadOnly );
-        connect( m_pushButtonAdd, SIGNAL( clicked() ), this, SLOT( slotAdd() ) );
+        connect( m_pushButtonAdd, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotAdd() ) );
 
         m_pushButtonEdit = new TQPushButton( i18n( "Edit" ), this );
         layout->addWidget( m_pushButtonEdit, 2, 1 );
         m_pushButtonEdit->setIconSet( TQIconSet( SmallIcon( "edit" ) ) );
-        connect( m_pushButtonEdit, SIGNAL( clicked() ), this, SLOT( slotEdit() ) );
+        connect( m_pushButtonEdit, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotEdit() ) );
 
         m_pushButtonToggle = new TQPushButton( i18n( "Toggle" ), this );
         layout->addWidget( m_pushButtonToggle, 3, 1 );
         m_pushButtonToggle->setIconSet( TQIconSet( SmallIcon( "flag" ) ) );
-        connect( m_pushButtonToggle, SIGNAL( clicked() ), this, SLOT( slotToggle() ) );
+        connect( m_pushButtonToggle, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotToggle() ) );
 
         m_pushButtonDelete = new TQPushButton( i18n( "Delete" ), this );
         layout->addWidget( m_pushButtonDelete, 4, 1 );
         m_pushButtonDelete->setIconSet( TQIconSet( SmallIcon( "edit-delete" ) ) );
-        connect( m_pushButtonDelete, SIGNAL( clicked() ), this, SLOT( slotDelete() ) );
+        connect( m_pushButtonDelete, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotDelete() ) );
 
         m_pushButtonUp = new TQPushButton( i18n( "Up" ), this );
         layout->addWidget( m_pushButtonUp, 5, 1 );
         m_pushButtonUp->setIconSet( TQIconSet( SmallIcon( "go-up" ) ) );
-        connect( m_pushButtonUp, SIGNAL( clicked() ), this, SLOT( slotUp() ) );
+        connect( m_pushButtonUp, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotUp() ) );
 
         m_pushButtonDown = new TQPushButton( i18n( "Down" ), this );
         layout->addWidget( m_pushButtonDown, 6, 1 );
         m_pushButtonDown->setIconSet( TQIconSet( SmallIcon( "go-down" ) ) );
-        connect( m_pushButtonDown, SIGNAL( clicked() ), this, SLOT( slotDown() ) );
+        connect( m_pushButtonDown, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotDown() ) );
     }
 
 }
