@@ -309,7 +309,7 @@ namespace KBibTeX
             m_currentParser = m_queryQueue.front().parser;
             TDEIO::Job *job = TDEIO::storedGet( m_queryQueue.front().url, FALSE, FALSE );
             m_queryQueue.pop_front();
-            connect( job, SIGNAL( result( TDEIO::Job * ) ), this, SLOT( getData( TDEIO::Job * ) ) );
+            connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( getData( TDEIO::Job * ) ) );
         }
     }
 
