@@ -92,11 +92,11 @@ namespace KBibTeX
         comboBoxField = new KComboBox( false, this );
         hLayout->addWidget( comboBoxField );
         label->setBuddy( comboBoxField );
-        connect( clearSearchText, SIGNAL( clicked() ), lineEditQuery, SLOT( clear() ) );
-        connect( lineEditQuery, SIGNAL( textChanged( const TQString& ) ), this, SLOT( slotTextChanged( const TQString& ) ) );
+        connect( clearSearchText, TQ_SIGNAL( clicked() ), lineEditQuery, TQ_SLOT( clear() ) );
+        connect( lineEditQuery, TQ_SIGNAL( textChanged( const TQString& ) ), this, TQ_SLOT( slotTextChanged( const TQString& ) ) );
         hLayout->setStretchFactor( lineEditQuery, 5 );
-        connect( lineEditQuery, SIGNAL( returnPressed() ), this, SIGNAL( startSearch() ) );
-        connect( lineEditQuery, SIGNAL( returnPressed( const TQString& ) ), completionQuery, SLOT( addItem( const TQString& ) ) );
+        connect( lineEditQuery, TQ_SIGNAL( returnPressed() ), this, TQ_SIGNAL( startSearch() ) );
+        connect( lineEditQuery, TQ_SIGNAL( returnPressed( const TQString& ) ), completionQuery, TQ_SLOT( addItem( const TQString& ) ) );
 
         hLayout = new TQHBoxLayout( );
         vLayout->addLayout( hLayout );
@@ -112,7 +112,7 @@ namespace KBibTeX
         hLayout->setStretchFactor( checkBoxYear, 1 );
         checkBoxYear->setChecked( true );
         hLayout->addWidget( checkBoxYear );
-        connect( checkBoxYear, SIGNAL( toggled( bool ) ), this, SLOT( slotYearCheckToggled() ) );
+        connect( checkBoxYear, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( slotYearCheckToggled() ) );
         comboBoxYear = new KComboBox( false, this );
         hLayout->setStretchFactor( comboBoxYear, 3 );
         hLayout->addWidget( comboBoxYear );
