@@ -17,11 +17,11 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-#include <ntqlayout.h>
-#include <ntqlabel.h>
-#include <ntqspinbox.h>
-#include <ntqbuffer.h>
-#include <ntqfile.h>
+#include <tqlayout.h>
+#include <tqlabel.h>
+#include <tqspinbox.h>
+#include <tqbuffer.h>
+#include <tqfile.h>
 
 #include <kpushbutton.h>
 #include <tdelocale.h>
@@ -31,8 +31,8 @@
 #include <tdeio/job.h>
 #include <tdeio/netaccess.h>
 
-#include <settings.h>
-#include <fileimporterris.h>
+#include "settings.h"
+#include "fileimporterris.h"
 #include "webquerysciencedirect.h"
 
 namespace KBibTeX
@@ -87,11 +87,11 @@ namespace KBibTeX
         TDECompletion *completionQuery = lineEditQuery->completionObject();
         hLayout->addWidget( lineEditQuery );
         label->setBuddy( lineEditQuery );
-        connect( clearSearchText, SIGNAL( clicked() ), lineEditQuery, SLOT( clear() ) );
-        connect( lineEditQuery, SIGNAL( textChanged( const TQString& ) ), this, SLOT( slotTextChangedSD( ) ) );
+        connect( clearSearchText, TQ_SIGNAL( clicked() ), lineEditQuery, TQ_SLOT( clear() ) );
+        connect( lineEditQuery, TQ_SIGNAL( textChanged( const TQString& ) ), this, TQ_SLOT( slotTextChangedSD( ) ) );
         hLayout->setStretchFactor( lineEditQuery, 7 );
-        connect( lineEditQuery, SIGNAL( returnPressed() ), this, SIGNAL( startSearch() ) );
-        connect( lineEditQuery, SIGNAL( returnPressed( const TQString& ) ), completionQuery, SLOT( addItem( const TQString& ) ) );
+        connect( lineEditQuery, TQ_SIGNAL( returnPressed() ), this, TQ_SIGNAL( startSearch() ) );
+        connect( lineEditQuery, TQ_SIGNAL( returnPressed( const TQString& ) ), completionQuery, TQ_SLOT( addItem( const TQString& ) ) );
 
 
         hLayout = new TQHBoxLayout( );
@@ -106,11 +106,11 @@ namespace KBibTeX
         completionQuery = lineEditAuthor->completionObject();
         hLayout->addWidget( lineEditAuthor );
         label->setBuddy( lineEditAuthor );
-        connect( clearAuthor, SIGNAL( clicked() ), lineEditAuthor, SLOT( clear() ) );
-        connect( lineEditAuthor, SIGNAL( textChanged( const TQString& ) ), this, SLOT( slotTextChangedSD( ) ) );
+        connect( clearAuthor, TQ_SIGNAL( clicked() ), lineEditAuthor, TQ_SLOT( clear() ) );
+        connect( lineEditAuthor, TQ_SIGNAL( textChanged( const TQString& ) ), this, TQ_SLOT( slotTextChangedSD( ) ) );
         hLayout->setStretchFactor( lineEditAuthor, 7 );
-        connect( lineEditAuthor, SIGNAL( returnPressed() ), this, SIGNAL( startSearch() ) );
-        connect( lineEditAuthor, SIGNAL( returnPressed( const TQString& ) ), completionQuery, SLOT( addItem( const TQString& ) ) );
+        connect( lineEditAuthor, TQ_SIGNAL( returnPressed() ), this, TQ_SIGNAL( startSearch() ) );
+        connect( lineEditAuthor, TQ_SIGNAL( returnPressed( const TQString& ) ), completionQuery, TQ_SLOT( addItem( const TQString& ) ) );
 
         hLayout->addSpacing( KDialog::spacingHint() * 2 );
 
@@ -123,11 +123,11 @@ namespace KBibTeX
         completionQuery = lineEditJournal->completionObject();
         hLayout->addWidget( lineEditJournal );
         label->setBuddy( lineEditJournal );
-        connect( clearJournal, SIGNAL( clicked() ), lineEditJournal, SLOT( clear() ) );
-        connect( lineEditJournal, SIGNAL( textChanged( const TQString& ) ), this, SLOT( slotTextChangedSD( ) ) );
+        connect( clearJournal, TQ_SIGNAL( clicked() ), lineEditJournal, TQ_SLOT( clear() ) );
+        connect( lineEditJournal, TQ_SIGNAL( textChanged( const TQString& ) ), this, TQ_SLOT( slotTextChangedSD( ) ) );
         hLayout->setStretchFactor( lineEditJournal, 4 );
-        connect( lineEditJournal, SIGNAL( returnPressed() ), this, SIGNAL( startSearch() ) );
-        connect( lineEditJournal, SIGNAL( returnPressed( const TQString& ) ), completionQuery, SLOT( addItem( const TQString& ) ) );
+        connect( lineEditJournal, TQ_SIGNAL( returnPressed() ), this, TQ_SIGNAL( startSearch() ) );
+        connect( lineEditJournal, TQ_SIGNAL( returnPressed( const TQString& ) ), completionQuery, TQ_SLOT( addItem( const TQString& ) ) );
 
         hLayout = new TQHBoxLayout( );
         vLayout->addLayout( hLayout );
@@ -138,7 +138,7 @@ namespace KBibTeX
         hLayout->addWidget( lineEditVolume );
         hLayout->setStretchFactor( lineEditVolume, 1 );
         label->setBuddy( lineEditVolume );
-        connect( lineEditVolume, SIGNAL( returnPressed() ), this, SIGNAL( startSearch() ) );
+        connect( lineEditVolume, TQ_SIGNAL( returnPressed() ), this, TQ_SIGNAL( startSearch() ) );
 
         hLayout->addSpacing( KDialog::spacingHint() * 2 );
 
@@ -148,7 +148,7 @@ namespace KBibTeX
         hLayout->addWidget( lineEditIssue );
         label->setBuddy( lineEditIssue );
         hLayout->setStretchFactor( lineEditIssue, 1 );
-        connect( lineEditIssue, SIGNAL( returnPressed() ), this, SIGNAL( startSearch() ) );
+        connect( lineEditIssue, TQ_SIGNAL( returnPressed() ), this, TQ_SIGNAL( startSearch() ) );
 
         hLayout->addSpacing( KDialog::spacingHint() * 2 );
 
@@ -158,7 +158,7 @@ namespace KBibTeX
         hLayout->addWidget( lineEditPage );
         hLayout->setStretchFactor( lineEditPage, 1 );
         label->setBuddy( lineEditPage );
-        connect( lineEditPage, SIGNAL( returnPressed() ), this, SIGNAL( startSearch() ) );
+        connect( lineEditPage, TQ_SIGNAL( returnPressed() ), this, TQ_SIGNAL( startSearch() ) );
 
         hLayout->addSpacing( KDialog::spacingHint() * 2 );
 
@@ -365,8 +365,8 @@ namespace KBibTeX
         KURL url = KURL( "http://www.sciencedirect.com/science" );
         TDEIO::TransferJob *job = TDEIO::http_post( url, data.utf8(), false );
         job->addMetaData( "content-type", "Content-Type: application/x-www-form-urlencoded" );
-        connect( job, SIGNAL( data( TDEIO::Job *, const TQByteArray & ) ), this, SLOT( slotData( TDEIO::Job *, const TQByteArray & ) ) );
-        connect( job, SIGNAL( result( TDEIO::Job * ) ), this, SLOT( slotResult( TDEIO::Job * ) ) );
+        connect( job, TQ_SIGNAL( data( TDEIO::Job *, const TQByteArray & ) ), this, TQ_SLOT( slotData( TDEIO::Job *, const TQByteArray & ) ) );
+        connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( slotResult( TDEIO::Job * ) ) );
 
         return true;
     }
